<?php

namespace App\Http\Controllers\Web;

use App\Http\Controllers\Controller;
use App\Mail\ResetCode;
use App\Models\Banner;
use App\Models\Category;
use App\Models\Product;
use App\Models\Setting;
use App\User;
use Carbon\Carbon;
use Illuminate\Http\Request;

class HomeController extends Controller
{
    public function index()
    {
        $cat_id = Setting::first() != null ? Setting::first()->value('category_id') : 0;
        $banners = Banner::whereShowHome('true')->inRandomOrder()->paginate(3);
        $home_categories = Category::where(['status' => 'active', 'parent_id' => $cat_id])->get();
        $taps_categories = Category::whereParentId(null)->get();
        $rows = Product::OrderByDesc('created_at')->get();
        \Session::forget('ads_type_session');
        \Session::forget('city_id_session');
        \Session::forget('county_id_session');
        \Session::forget('grand_id_session');
        \Session::forget('parent_id_session');
        \Session::forget('category_id_session');

        if (\Auth::check()){
            $user = \Auth::user();
            if (Carbon::parse(\Auth::user()->end_subscription) > Carbon::now()){

                $user->vip = 'true';
                $user->update();
            }else{
                $user->vip = 'false';
            }
        }
        return view('web.index', compact('banners', 'taps_categories', 'rows', 'home_categories'));
    }

    public function change_language($lang)
    {
        if ($lang == 'en' || $lang == 'ar') {
            if (!\Session::has('language')) {
                \Session::put('language', $lang);
            } else {
                \Session::put('language', $lang);
            }


            return redirect()->back();

        } else {
            return redirect('/home');
        }
    }

    public function user_login(Request $request)
    {
        $this->validate($request, [
            'mobile' => 'required',
            'password' => 'required'
        ]);
        if (\Auth::attempt(['mobile' => $request['mobile'], 'password' => $request['password'], 'status' => 'active', 'type' => 'user'])) {
            $user = User::whereMobile($request->mobile)->first();
            $user->online = 'true';
            $user->update();
            return redirect()->back()->with('message', \Lang::get('data.welcome'));
        } else {
            return redirect()->back()->with('error', \Lang::get('data.error_login_credentials'));
        }
    }

    public function user_register(Request $request)
    {
        $this->validate($request, [
            'mobile' => 'required|unique:users,mobile',
            'name' => 'required|unique:users,name',
            'email' => 'email|nullable|unique:users,email',
            'city_id' => 'required|exists:cities,id',
            'password' => 'required|confirmed',
            'password_confirmation' => 'required',
            'country_code'=>'required'
        ]);

        $mobile = $request['country_code'].$request['mobile'];

        $user = User::create([
            'mobile' =>  $mobile,
            'name' => $request['name'],
            'city_id' => $request['city_id'],
            'password' => bcrypt($request['password']),
            'online' => 'true',
            'email'=>$request['email'],
        ]);
        \Auth::login($user);
        return redirect()->back()->with('message', \Lang::get('data.welcome'));
    }

    public function logout()
    {
        \Auth::user()->update([
            'online' => 'false'
        ]);
        \Auth::logout();

        return redirect()->route('home')->with('message', \Lang::get('data.logout'));
    }

    public function update_forget_password(Request $request)
    {
        $user = User::whereMobile($request->mobile)->first();


        $code = rand(1111, 9999);
        $user->code = $code;
        $user->update();
        // email code

        \Mail::to($user->email)->send(new ResetCode($code));

        \Session::put('mobile', $user->mobile);
        \Session::put('country_code', $request['country_code']);
        return response()->json(['status' => 1, 'code_sent' => \Lang::get('data.code_sent')]);


    }

    public function forget_password(Request $request)
    {
        $this->validate($request, [
            'mobile' => 'required',
        ]);


        $user = User::whereMobile($request['mobile'])->first();


        if ($user) {
            $code = rand(1111, 9999);
            $user->code = $code;
            $user->update();
            // sms code
            \Mail::to($request['email'])->send(new ResetCode($code));
            \Session::put('email', $user->email);
            \Session::put('mobile', $user->mobile);
            \Session::put('country_code', $request['country_code']);
            return redirect()->route('forget_password_user');

        } else {
            return redirect()->back()->with('error', \Lang::get('data.mobile_not_found'));
        }

    }

    public function user_rest_password(Request $request)
    {
        $this->validate($request, [
            'code' => 'required'
        ]);

        $code = implode("", $request['code']);
        $email = \Session::get('email');
        $mobile = \Session::get('mobile');
        $user = User::whereMobile($mobile)->first();
        if ($user->code == $code) {
            \Session::put('user_id', $user->id);
            return view('web.reset_password');
        } else {
            return back()->with('error', \Lang::get('data.error_code'));
        }
    }

    public function forget_password_user()
    {
        return view('web.forget_code');
    }

    public function update_password(Request $request)
    {
        $this->validate($request, [
            'password' => 'required|confirmed',
            'password_confirmation' => 'required'
        ]);
        $user_id = \Session::get('user_id');
        $user = User::find($user_id);
        $user->password = bcrypt($request['password']);
        $user->update();
        \Auth::login($user);
        return redirect()->route('home')->with('message', \Lang::get('data.welcome'));
    }

    public function special_ads()
    {
        return view('web.data.special_ads');
    }

}
